@@ -50,8 +50,12 @@
 /*  fddmat scalar, the leading dimension of the matrix dmat */
 /*  n      the dimension of dmat and dvec (int) */
 /*  amat   nxq matrix, the matrix A from above (dp) [ A=(A1 A2)^T ] */
+/*         *** ENTRIES CORRESPONDING TO EQUALITY CONSTRAINTS MAY HAVE */
+/*             CHANGED SIGNES ON EXIT *** */
 /*  bvec   qx1 vector, the vector of constants b in the constraints (dp) */
 /*         [ b = (b1^T b2^T)^T ] */
+/*         *** ENTRIES CORRESPONDING TO EQUALITY CONSTRAINTS MAY HAVE */
+/*             CHANGED SIGNES ON EXIT *** */
 /*  fdamat the first dimension of amat as declared in the calling program. */
 /*         fdamat >= n !! */
 /*  q      integer, the number of constraints. */
@@ -70,12 +74,10 @@
 /*  iter  2x1 vector, first component gives the number of "main" */
 /*        iterations, the second one says how many constraints were */
 /*        deleted after they became active */
-/*  miter integer, the maximal number of iterations */
 /*  ierr  integer, error code on exit, if */
 /*           ierr = 0, no problems */
 /*           ierr = 1, the minimization problem has no solution */
-/*           ierr = 2, the maximal number of iterations was exceeded */
-/*           ierr = 3, problems with decomposing D, in this case sol */
+/*           ierr = 2, problems with decomposing D, in this case sol */
 /*                     contains garbage!! */
 
 /*  Working space: */
@@ -83,11 +85,11 @@
 /*        where r=min(n,q) */
 
 /* Subroutine */ int qpgen2_(dmat, dvec, fddmat, n, sol, crval, amat, bvec, 
-	fdamat, q, meq, iact, nact, iter, miter, work, ierr)
+	fdamat, q, meq, iact, nact, iter, work, ierr)
 doublereal *dmat, *dvec;
 integer *fddmat, *n;
 doublereal *sol, *crval, *amat, *bvec;
-integer *fdamat, *q, *meq, *iact, *nact, *iter, *miter;
+integer *fdamat, *q, *meq, *iact, *nact, *iter;
 doublereal *work;
 integer *ierr;
 {
@@ -153,7 +155,7 @@ integer *ierr;
     if (*ierr == 0) {
 	dpofa_(&dmat[dmat_offset], fddmat, n, &info);
 	if (info != 0) {
-	    *ierr = 3;
+	    *ierr = 2;
 	    goto L999;
 	}
 	dposl_(&dmat[dmat_offset], fddmat, n, &dvec[1]);
@@ -238,10 +240,6 @@ L50:
 /* start a new iteration */
 
     ++iter[1];
-    if (iter[1] == *miter) {
-	*ierr = 2;
-	goto L999;
-    }
 
 /* calculate all constraints and check which are still violated */
 /* for the equality constraints we have to check whether the normal */
@@ -613,6 +611,7 @@ L160:
 				;
 /* L191: */
 		    }
+		    bvec[i__] = -bvec[i__];
 		}
 	    }
 	    goto L700;
